Sparklines

Total Value | Percentage of Portfolio | Last 10 days | Volume
$32,554 | 15% |  |
$23,533 | 7% |  |
$54,276 | 9% |  |
$11,533 | 2% |  |

<div> <div class="row"> <div class="col-md-4"> <div id="chart-spark1"> <apexchart type="area" height="160" :options="chartOptions" :series="series"></apexchart> </div> </div> <div class="col-md-4"> <div id="chart-spark2"> <apexchart type="area" height="160" :options="chartOptionsSpark2" :series="seriesSpark2"></apexchart> </div> </div> <div class="col-md-4"> <div id="chart-spark3"> <apexchart type="area" height="160" :options="chartOptionsSpark3" :series="seriesSpark3"></apexchart> </div> </div> </div> <div class="row"> <table> <thead> <th>Total Value</th> <th>Percentage of Portfolio</th> <th>Last 10 days</th> <th>Volume</th> </thead> <tbody> <tr> <td>$32,554</td> <td>15%</td> <td> <div id="chart-1"> <apexchart type="line" height="35" width="100" :options="chartOptions1" :series="series1"></apexchart> </div> </td> <td> <div id="chart-5"> <apexchart type="bar" height="35" width="100" :options="chartOptions5" :series="series5"></apexchart> </div> </td> </tr> <tr> <td>$23,533</td> <td>7%</td> <td> <div id="chart-2"> <apexchart type="line" height="35" width="100" :options="chartOptions2" :series="series2"></apexchart> </div> </td> <td> <div id="chart-6"> <apexchart type="bar" height="35" width="100" :options="chartOptions6" :series="series6"></apexchart> </div> </td> </tr> <tr> <td>$54,276</td> <td>9%</td> <td> <div id="chart-3"> <apexchart type="pie" height="40" width="40" :options="chartOptions3" :series="series3"></apexchart> </div> </td> <td> <div id="chart-7"> <apexchart type="radialBar" height="50" width="50" :options="chartOptions7" :series="series7"></apexchart> </div> </td> </tr> <tr> <td>$11,533</td> <td>2%</td> <td> <div id="chart-4"> <apexchart type="donut" height="40" width="40" :options="chartOptions4" :series="series4"></apexchart> </div> </td> <td> <div id="chart-8"> <apexchart type="radialBar" height="40" width="40" :options="chartOptions8" :series="series8"></apexchart> </div> </td> </tr> </tbody> </table> </div> </div>